==> igniteui-react-18.5.1.tgz: package/esm2015/lib/Step.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { StepStepType_$type } from "./StepStepType";
import { StepTitlePosition_$type } from "./StepTitlePosition";
import { StepOrientation_$type } from "./StepOrientation";
/**
 * @hidden
 */
export let Step = /*@__PURE__*/ (() => {
    class Step extends BaseElement {
        constructor() {
            super(...arguments);
            this.d = new WCNativeHelper();
            this.p = null;
        }
        get e() {
            return this.d;
        }
        get nativeElement() {
            return this.p;
        }
        set nativeElement(a) {
            this.p = a;
            this.d.o = this.p;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get j() {
            let ret_ = this.e.n("invalid");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.e.v("invalid", value_);
        }
        get f() {
            let ret_ = this.e.n("active");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.e.v("active", value_);
        }
        get l() {
            let ret_ = this.e.n("optional");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.e.v("optional", value_);
        }
        get i() {
            let ret_ = this.e.n("disabled");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.e.v("disabled", value_);
        }
        get g() {
            let ret_ = this.e.n("complete");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.e.v("complete", value_);
        }
        get m() {
            let ret_ = this.e.n("previousComplete");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.e.v("previousComplete", value_);
        }
        get b() {
            let ret_ = this.e.n("stepType");
            ret_ = enumGetBox(StepStepType_$type, EnumUtil.getEnumValue(StepStepType_$type, this.e.f(StepStepType_$type, ret_)));
            return EnumUtil.getEnumValue(StepStepType_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(StepStepType_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("stepType", value_);
        }
        get c() {
            let ret_ = this.e.n("titlePosition");
            ret_ = enumGetBox(StepTitlePosition_$type, EnumUtil.getEnumValue(StepTitlePosition_$type, this.e.f(StepTitlePosition_$type, ret_)));
            return EnumUtil.getEnumValue(StepTitlePosition_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(StepTitlePosition_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("titlePosition", value_);
        }
        get a() {
            let ret_ = this.e.n("orientation");
            ret_ = enumGetBox(StepOrientation_$type, EnumUtil.getEnumValue(StepOrientation_$type, this.e.f(StepOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(StepOrientation_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(StepOrientation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("orientation", value_);
        }
        get o() {
            let ret_ = this.e.n("index");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.e.v("index", value_);
        }
        get h() {
            let ret_ = this.e.n("contentTop");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.e.v("contentTop", value_);
        }
        get k() {
            let ret_ = this.e.n("linearDisabled");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.e.v("linearDisabled", value_);
        }
        get n() {
            let ret_ = this.e.n("visited");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.e.v("visited", value_);
        }
    }
    Step.$t = /*@__PURE__*/ markType(Step, 'Step', BaseElement.$);
    return Step;
})();

==> igniteui-react-18.6.0.tgz: package/esm2015/lib/Step.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, markType } from "igniteui-react-core";
import { StepType_$type } from "./StepType";
import { StepDirection_$type } from "./StepDirection";
/**
 * @hidden
 */
export let Step = /*@__PURE__*/ (() => {
    class Step extends BaseElement {
        constructor() {
            super(...arguments);
            this.a = new WCNativeHelper();
            this.h = null;
        }
        get b() {
            return this.a;
        }
        get nativeElement() {
            return this.h;
        }
        set nativeElement(a) {
            this.h = a;
            this.a.o = this.h;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get f() {
            let ret_ = this.b.n("invalid");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.b.v("invalid", value_);
        }
        get c() {
            let ret_ = this.b.n("active");
            return ret_;
        }
        set c(a) {
            let value_ = a;
            this.b.v("active", value_);
        }
        get g() {
            let ret_ = this.b.n("optional");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.b.v("optional", value_);
        }
        get e() {
            let ret_ = this.b.n("disabled");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.b.v("disabled", value_);
        }
        get d() {
            let ret_ = this.b.n("complete");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.b.v("complete", value_);
        }
        k(a, b) {
            this.nativeElement.toggleAnimation(this.b.i(enumGetBox(StepType_$type, a)), this.b.i(enumGetBox(StepDirection_$type, b)));
        }
    }
    Step.$t = /*@__PURE__*/ markType(Step, 'Step', BaseElement.$);
    return Step;
})();
